use strict;
use Test::More tests => 10;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var a = b( 1,2,b );
  var c = d( f,g,h );
  var e = f( h );
  var g = h();
  var i = j( k());
};

=for later

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//CallMemberArgs');
is(scalar @nodes, 6, "6 argument list expressions found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//ArgumentList[./ArgumentList]');
is(scalar @nodes, 0, "ArgumentList gets flattened correctly")
  or do { diag $_->toString for @nodes;
          diag $tree->toString };

@nodes = $tree->findnodes('//CallMemberArgs/ArgumentList/CallMemberArgs/ArgumentList');
is(scalar @nodes, 1, "One nested ArgumentList found")
  or do { diag $_->toString for @nodes;
          diag $tree->toString };

@nodes = $tree->findnodes('//CallMemberArgs[./Identifier[@name="Callee"]/text() = "h"]/ArgumentList');
is(scalar @nodes, 1, "h() is declared, and has an argument list")
  or do { diag $_->toString for @nodes };

@nodes = $tree->findnodes('//CallMemberArgs[./Identifier[@name="Callee"]/text() = "h"]/ArgumentList/*');
is(scalar @nodes, 0, "And that argument list is empty")
  or do { diag $_->toString for @nodes };

