use strict;
use Test::More tests => 25;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  0;
  1;
  2;
  3;
  4;
  5;
  6;
  7;
  8;
  9;
  +0;
  +1;
  +2;
  +3;
  +4;
  +5;
  +6;
  +7;
  +8;
  +9;
  -0;
  -1;
  -2;
  -3;
  -4;
  -5;
  -6;
  -7;
  -8;
  -9;
  10;
  100;
  1000;
  10.5;
  0.7;
  .6;
  .6E6;
  .6E-6;
  .6E+6;
  .6e6;
  .6e-6;
  .6e+6;
  0E0;
  10E0;
  Infinity;
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse')
  or diag Dumper($tree);

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//Number');
is(scalar @nodes, 45, "45 numeric (decimal) literals found")
  or do { diag Dumper \@nodes; diag $tree->toString };

my %values;

$JS =~ s/^\s*//;
$JS =~ s/\s*$//;
for my $num (split /;\s*/sm, $JS) {
  my $key = $num eq 'Infinity' ? $num : abs 0+$num;
  $values{$key}++
};

for my $value (sort keys %values) {
  my $expr;
  if ($value =~ /"/) {
    $expr = qq{'$value'}
  } elsif ($value =~ /'/) {
    $expr = qq{"$value"};
  } else {
    $expr = $value;
    $expr =~ s/'/&quot;/g;
    $expr = qq{'$expr'};
  };
  @nodes = $tree->findnodes("//Number[text() = $expr]");
  is(scalar @nodes, $values{$value}, "$values{$value} numeric literal(s) >>$value<< found")
    or do { diag $tree->toString; diag $expr; };
};
