use strict;
use Test::More tests => 11;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  foo();
  alert();
  alert('Hello World');
  alert('Hello World','This is a test');
  alert(alert('Sound klaxons'),'Hello World','This is a test');
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse')
  or diag Dumper($tree);
  
my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//CallMemberArgs');
is(scalar @nodes, 6, "6 calls found")
  or do { diag $_->toString for $tree->findnodes('//CallMemberArgs' ) };

@nodes = $tree->findnodes('//CallMemberArgs[./ArgumentList and ./Identifier/text() = "alert"]');
is(scalar @nodes, 5, "5 calls to C<alert> found")
  or do { diag $_->toString for $tree->findnodes('//CallMemberArgs') };

@nodes = $tree->findnodes('//CallMemberArgs[./ArgumentList[count(*) = 0] and ./Identifier/text() = "alert"]');
is(scalar @nodes, 1, "1 call to C<alert> without parameters found")
  or do { diag $_->toString for $tree->findnodes('//CallMemberArgs') };

@nodes = $tree->findnodes('//CallMemberArgs[./ArgumentList[count(*) = 2] and ./Identifier/text() = "alert"]');
is(scalar @nodes, 1, "2 calls to C<alert> with 1 parameter found")
  or do { diag $_->toString for $tree->findnodes('//CallMemberArgs') };

@nodes = $tree->findnodes('//CallMemberArgs[./ArgumentList[count(*) = 2] and ./Identifier/text() = "alert"]');
is(scalar @nodes, 1, "1 call to C<alert> with 2 parameters found")
  or do { diag $_->toString for $tree->findnodes('//CallMemberArgs') };

@nodes = $tree->findnodes('//CallMemberArgs[.//CallMemberArgs]');
is(scalar @nodes, 1, "One nested member call expression found")
  or do { diag $_->toString for $tree->findnodes('//CallMemberArgs') };

