use strict;
use Test::More tests => 26;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  0x0;
  0x1;
  0x2;
  0x3;
  0x4;
  0x5;
  0x6;
  0x7;
  0x8;
  0x9;
  0xA;
  0xB;
  0xC;
  0xD;
  0xE;
  0xF;
  0xa;
  0xb;
  0xc;
  0xd;
  0xe;
  0xf;
  0xdeadbeef;
  0xf00d;
  0x007babe5;
  0x31337;
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse')
  or diag Dumper($tree);

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//Number');
is(scalar @nodes, 26, "26 numeric (hexadecimal) literals found")
  or do { diag Dumper \@nodes; diag $tree->toString };

my %values;

$JS =~ s/^\s*//;
$JS =~ s/\s*$//;
for my $num (split /;\s*/sm, $JS) {
  my $key = $num eq 'Infinity' ? $num : 0+ hex $num;
  $values{$key}++
};

for my $value (sort keys %values) {
  my $expr;
  if ($value =~ /"/) {
    $expr = qq{'$value'}
  } elsif ($value =~ /'/) {
    $expr = qq{"$value"};
  } else {
    $expr = $value;
    $expr =~ s/'/&quot;/g;
    $expr = qq{'$expr'};
  };
  @nodes = $tree->findnodes("//Number[text() = $expr]");
  is(scalar @nodes, $values{$value}, "$values{$value} numeric literal(s) >>$value<< found")
    or do { diag $tree->toString; diag $expr; };
};
