use strict;
use Test::More tests => 9;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var a = 1++;
  var b = 1--;
};

=for later
  var c = 1++ ++;

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//VariableStatement');
is(scalar @nodes, 2, "2 variable declarations found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//PostfixOperator');
is(scalar @nodes, 2, "2 unary postfix operations declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//PostfixOperator[text()="++"]');
is(scalar @nodes, 1, "1 postfix increment declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

@nodes = $tree->findnodes('//PostfixOperator[text()="--"]');
is(scalar @nodes, 1, "1 postfix decrement declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

#@nodes = $tree->findnodes('//PostfixExpression[PostfixOperator[text()="++"]][PostfixExpression[PostfixOperator[text()="++"]]]');
#is(scalar @nodes, 1, "1 double postincrement declared")
#  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };


