use strict;
use Test::More tests => 12;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var a = 1 < 2;
  var b = 3 > 4;
  var c = 5 >= 6;
  var d = 7 <= 8;
  var e = 9 instanceof 10;
  var f = 11 in (12,13);
};

=for later

??? What should go here?

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//RelationalExpression');
is(scalar @nodes, 6, "6 relational expressions found")
  or do { diag $_->toString for $tree->findnodes('//RelationalExpression' ) };

@nodes = $tree->findnodes('//RelationalExpression[.//Number/text() = 1 and .//Number/text() = 2 and ./RelationalOperator/text() = "<"]');
is(scalar @nodes, 1, "'1 < 2' expression found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//RelationalExpression[.//Number/text() = 3 and .//Number/text() = 4 and ./RelationalOperator/text() = ">"]');
is(scalar @nodes, 1, "'3 > 4' expression found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//RelationalExpression[.//Number/text() = 5 and .//Number/text() = 6 and ./RelationalOperator/text() = ">="]');
is(scalar @nodes, 1, "'5 >= 6' expression found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//RelationalExpression[.//Number/text() = 7 and .//Number/text() = 8 and ./RelationalOperator/text() = "<="]');
is(scalar @nodes, 1, "'7 <= 8' expression found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//RelationalExpression[.//Number/text() = 9 and .//Number/text() = 10 and ./RelationalOperator/text() = "instanceof"]');
is(scalar @nodes, 1, "'9 instanceof 10' expression found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//RelationalExpression[.//Expression and .//Number/text() = 11 and ./RelationalOperator/text() = "in"]');
is(scalar @nodes, 1, "'11 instanceof 12,13' expression found")
  or do { diag $_->toString for $tree->findnodes('//RelationalExpression[./RelationalOperator/text() = "in"]') };


