use strict;
use Test::More tests => 8;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var a = b( 1,2,b );
  var c = d( f,g,h );
  var e = f( h );
  var g = h();
  var i = j( k());
};

=for later

=cut

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree, undef, 'JS was parsed successfully');

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//SourceElements');
is(scalar @nodes, 1, "1 source element container found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//SourceElements/*');
is(scalar @nodes, 5, "5 source elements found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//SourceElements[./SourceElements]');
is(scalar @nodes, 0, "Source element container gets flattened correctly")
  or do { diag $_->toString for @nodes;
          diag $tree->toString };

