use strict;
use Test::More tests => 7;
use Data::Dumper;
BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  for (var a;a!=0;a--) alert("Hello World!");
  for (var b=10;b!=0;b--) alert("b");
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");
isn't($tree,undef,'Got a parse');

my @nodes;

@nodes = $tree->findnodes('//CForStatement');
is(scalar @nodes, 2, "2 for statements found")
  or do { diag $_->toString for $tree->findnodes('//CForStatement' ) };

@nodes = $tree->findnodes('//CForStatement[./Statement//CallMemberArgs/Identifier/text() = "alert"]');
is(scalar @nodes, 2, "2 for statements calling 'alert()' found")
  or do { diag $_->toString for $tree->findnodes('//CForStatement' ) };

@nodes = $tree->findnodes('//CForStatement[.//VariableDeclaration[not( ./Initializer)]]');
is(scalar @nodes, 1, "1 for statement with an inline variable declaration without initialization found")
  or do { diag $_->toString for $tree->findnodes('//CForStatement' ) };

@nodes = $tree->findnodes('//CForStatement[.//VariableDeclaration/Initializer]');
is(scalar @nodes, 1, "1 for statement with an inline variable declaration and initialization found")
  or do { diag $_->toString for $tree->findnodes('//CForStatement' ) };

