use strict;
use Test::More tests => 16;
use Data::Dumper;
use Carp qw(croak);
use lib 't';
use testlib;

$Data::Dumper::Indent = 1;

BEGIN { use_ok('Javascript::PurePerl') };

my $JS = q{
  var i;

  var q = 1;

  var j,k,l;

  var m=2,n;

  var o,p=3;
};

my ($parser,$tree);
eval {
  $parser = Javascript::PurePerl->new();
  $tree = $parser->parse( code => $JS );
};
is($@,"","No crash parsing JS");

my @nodes = $tree->findnodes('/AST');
is(scalar @nodes, 1, "AST constructed correctly");

@nodes = $tree->findnodes('/AST/Program');
is(scalar @nodes, 1, "Program is top level node");

@nodes = $tree->findnodes('//VariableStatement');
is(scalar @nodes, 5, "5 variable declarations found")
  or do { diag Dumper \@nodes; diag $tree->toString };

@nodes = $tree->findnodes('//VariableDeclaration');
is(scalar @nodes, 9, "9 variables declared")
  or do { diag ($_->toString,"\n") for @nodes; diag $tree->toString };

for my $name (qw( i j k l m n o p q )) {
  @nodes = $tree->findnodes("//VariableDeclaration/Identifier[text()='$name']");
  is(scalar @nodes, 1, "$name variable is declared")
    or do { diag ($_->toString,"\n") for $tree->findnodes("//Identifier"); diag $tree->toString };
};

@nodes = $tree->findnodes('//Statement/VariableStatement');
is(scalar @nodes, 5, "All variable statements in the right place")
  or diag $tree->toString;


